@@ -6,14 +6,15 @@ https://gist.github.com/cynici/5865326
 
 """
 import importlib
-import itertools
 import math
 import re
+import traceback
 from typing import Dict, Tuple, Union, List
 
 import lxml
 import numpy as np
 import pandas as pd
+from lxml import etree
 
 from nexinfosys import case_sensitive
 from nexinfosys.command_generators import global_functions, IType, Issue, IssueLocation, parser_field_parsers
@@ -121,10 +122,13 @@ def call_udif_function(function_name, state: State = None):
 lcia_methods = None  # type: PartialRetrievalDictionary
 
 
-def lcia_method(indicator: str, method: str = None, horizon: str = None, compartment: str = None,
-                subcompartment: str = None, category: str = None,
+def lcia_method(method: str, category: str, indicator: str,
+                compartment: str = None,
+                subcompartment: str = None,
+                horizon: str = None, sum_if_multiple: bool = True,
                 state: State = None, lcia_methods_dict: Dict = None):
     """
+    Calculate the LCIA method indicator
 
     :param indicator: Indicator name
     :param method: LCIA method weighting
@@ -136,28 +140,38 @@ def lcia_method(indicator: str, method: str = None, horizon: str = None, compart
     :return: A dictionary with the indicators and calculated values
     """
     global lcia_methods
-    if not lcia_methods:
+    if not lcia_methods and lcia_methods_dict:
         lcia_methods = PartialRetrievalDictionary()
         from random import random
         for k, v in lcia_methods_dict.items():
+            # [0] m=Method,
+            # [1] t=caTegory,
+            # [2] d=inDicator,
+            # [3] h=Horizon,
+            # [4] i=Interface,
+            # [5] c=Compartment,
+            # [6] s=Subcompartment,
             _ = dict(m=k[0], t=k[1], d=k[2], h=k[3], i=k[4], c=k[5], s=k[6])
             # NOTE: a random() is generated just to grant that the tuple is unique
             lcia_methods.put(_, (v[0], v[1], v[2], random()))
 
-    if indicator is None or indicator.strip() == "":
+    if lcia_methods is None or \
+            indicator is None or indicator.strip() == "" or \
+            method is None or method.strip() == "" or \
+            category is None or category.strip() == "":
         return None
 
     k = dict(d=indicator)
     if method:
         k["m"] = method
+    if category:
+        k["t"] = category
     if horizon:
         k["h"] = horizon
     if compartment:
         k["c"] = compartment
     if subcompartment:
         k["s"] = subcompartment
-    if category:
-        k["t"] = category
 
     ms = lcia_methods.get(key=k, key_and_value=True)
     indices = create_dictionary()
@@ -208,13 +222,41 @@ def lcia_method(indicator: str, method: str = None, horizon: str = None, compart
         ind = np.sum(np.multiply(interfaces, weights))  # * ureg(indicator_unit)
         res[name] = ind
 
+    if sum_if_multiple:
+        res = sum(res.values())
+
     return res
 
 
+def starts_with(context, *args):
+    """
+
+    :return:
+    """
+    return args[0].startswith(args[1])
+
+
+def lower_case(context, text):
+    """
+
+    :param text:
+    :return:
+    """
+    if isinstance(text, list):
+        return [x.lower() for x in text]
+    elif isinstance(text, str):
+        return text.lower()
+    else:
+        return text
+
+
 def obtain_processors(xquery: str = None, processors_dom=None, processors_map=None):
     if xquery:
         try:
             processors = set()
+            ns = etree.FunctionNamespace(None)
+            ns["starts-with"] = starts_with
+            ns["lower-case"] = lower_case
             r = processors_dom.xpath(xquery if case_sensitive else xquery.lower())
             for e in r:
                 fname = e.get("fullname")
@@ -224,9 +266,9 @@ def obtain_processors(xquery: str = None, processors_dom=None, processors_map=No
                     pass  # Interfaces...
             return processors
         except lxml.etree.XPathEvalError:
+            traceback.print_exc()
             # TODO Try CSSSelector syntax
             # TODO Generate Issue
-            pass
     else:
         # ALL
         # TODO Probably this should not be used because it will normally imply double accounting
