@@ -1539,7 +1539,7 @@ def replace_string_from_dictionary(s: str, d: Dict[str, str]) -> str:
     """
     for k, v in sorted(d.items(), key=lambda item: len(item[1])):
         logging.debug(v)
-        s = re.sub(r"\b" + k + r"\b", v, s)
+        s = re.sub(r"\b" + k + r"\b", v, s, flags=re.IGNORECASE)
     return s
 
 # #####################################################################################################################
