@@ -391,7 +391,10 @@ def aggregate_generic(funct,
     if processors_selector:
         inv_map = {v: k for k, v in p_map.items()}
         processors = obtain_processors(processors_selector, serialized_model, p_map)
-        processor_names_ = set([inv_map[p] for p in processors])
+        if processors:
+            processor_names_ = set([inv_map[p] for p in processors])
+        else:
+            processor_names_ = None
     else:
         processor_names_ = None
     if processor_names is not None:
@@ -573,7 +576,10 @@ def calculate_scalar_indicators(indicators: List[Indicator],
         if indicator.processors_selector:
             inv_map = {v: k for k, v in p_map.items()}
             processors = obtain_processors(indicator.processors_selector, serialized_model, p_map)
-            processor_names = set([inv_map[p] for p in processors])
+            if processors:
+                processor_names = set([inv_map[p] for p in processors])
+            else:
+                processor_names = None
         else:
             processor_names = None
 
@@ -653,7 +659,10 @@ def calculate_scalar_indicators(indicators: List[Indicator],
         if indicator.processors_selector:
             inv_map = {v: k for k, v in p_map.items()}
             processors = obtain_processors(indicator.processors_selector, serialized_model, p_map)
-            processor_names = set([inv_map[p] for p in processors])
+            if processors:
+                processor_names = set([inv_map[p] for p in processors])
+            else:
+                processor_names = None
         else:
             processor_names = None
 
